/*
  Copyright (c) 2012 Dirk Willrodt <willrodt@zbh.uni-hamburg.de>
  Copyright (c) 2012 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef ENCDESC_HEADER_IO_H
#define ENCDESC_HEADER_IO_H

#include "core/error_api.h"
#include "extended/encdesc.h"

/* Write header information of <encdesc> to <FILE> <fp>.
   Returns 0 on success, 1 on error, sets <err> accordingly.
   TODO DW this function does more than that, it sets some bool within the
   header! This should be refactored. */
int encdesc_write_header(GtEncdesc *encdesc, FILE *fp, GtError *err);

/* Read header information of <encdesc> from <FILE> <fp>.
   Returns 0 on success, 1 on error, sets <err> accordingly.  */
int encdesc_read_header(GtEncdesc *encdesc, FILE *fp, GtError *err);

#endif
